/*--------------------------------------------------------------------------------------------------
  Name         :  KS108LCD.h
  Description  :  Header file for KS0108 graphic LCD driver.
  Version      :  1.5
  Author       :  Nickolay Zakrzhevsky
  Created      :  19 jan 2006
  Home page    :  www.md4u.ru/godo.html
  E-Mail       :  go@md4u.ru
--------------------------------------------------------------------------------------------------*/
#ifndef _KS108LCD_H_

#define _KS108LCD_H_

/* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !!!              WARNING correct LCD_DELAY_CNT for your frequency                      !!!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */

#define LCD_DELAY_CNT 10  //  For    16 MHz
//#define LCD_DELAY_CNT 5 //  For     8 MHz
//#define LCD_DELAY_CNT 0 //  For     1 MHz

// Display commands
#define DISPLAY_ON         0x3f
#define DISPLAY_OFF        0x3e
#define DISPLAY_STARTLINE  0xc0
#define DISPLAY_PAGE_SET   0xb8
#define DISPLAY_COLUMN_SET 0x40


//  ATMega PORT define for LCD.
#define CMD_PORT       PORTD
#define CMD_PORT_DIR    DDRD
#define DATA_PORT      PORTC
#define DATA_PORT_DIR   DDRC
#define DATA_PORT_READ  PINC

//  ATMega pinout for LCD.
#define LCD_DI   1    // Data/instruction
#define LCD_RW   64   // Data read/write
#define LCD_E    128  // E->L Enable signal
#define LCD_CS1  2    // Chip select for IC1
#define LCD_CS2  8    // Chip select for IC2
#define LCD_CS12 24   // Chip select for IC1&IC2 
#define LCD_RST  4    // Reset pin (low for reset)

typedef enum
{
    PIXEL_ON  =  0,
    PIXEL_OFF =  1,
    PIXEL_XOR =  2

} pix_format;

 void LcdInit       ( void);
 void LcdClear      ( void );
 void LcdReset      ( void); 
 void LcdChr        ( unsigned char ch, unsigned char   x,    unsigned char   y);
 void LcdStr        ( unsigned char   *dataPtr, unsigned char   x,    unsigned char   y  );
 void LcdDrawIntN   ( unsigned int ii, unsigned char nn, unsigned char   x,    unsigned char   y); 
 void LcdPixel      ( unsigned char x,unsigned char  y,unsigned char pix_format);
 void InvStr        ( unsigned char x,unsigned char y,unsigned char l);
 void SetStartLine  ( unsigned char line);
 void SetPage       ( unsigned char y);
 void SetColumn     ( unsigned char x);
 void SendLcdData   ( unsigned char value, unsigned char CS);
 void SendLcdCommand( unsigned char value, unsigned char CS);
 void LcdLine       ( unsigned char x1,unsigned char y1,unsigned char x2, unsigned char y2,unsigned char pix_format );
 unsigned char ReadLcdData  ( unsigned char CS);
 unsigned char ReadLcdStatus( unsigned char CS);

#endif  //  _KS108LCD_H_
