/*--------------------------------------------------------------------------------------------------
  Name         :  ks108_test.c
  Description  :  KS0108 LCD driver test program
  Version      :  1.5  
  Author       :  Nickolay Zakrzhevsky
  Created      :  19 jan 2006
  Home page    :  www.md4u.ru/godo.html
  E-Mail       :  go@md4u.ru
--------------------------------------------------------------------------------------------------*/

#include <iom32v.h>
#include <macros.h>
#include "KS108LCD.h" 

#define btn_left  128  // 7 
#define btn_right 16   // 4
#define btn_up    64   // 6
#define btn_down  32   // 5
#define btn_port  PINB  // no comment 

void port_init(void)
{
 PORTA = 0x00;  //
 DDRA  = 0x30;  //pin[4,5] - Leds
 
 PORTB = 0xF0; // pin[7,6,5,4] - "Up" for button input
 DDRB  = 0x00; //  
 
 PORTC = 0x00;  //LCD data 
 DDRC  = 0x00;  // init in LCD init
 
 PORTD = 0x00; // LCD command
 DDRD  = 0x00; // init in LCD init
}

//call this routine to initialize all peripherals
void init_devices(void)
{
 //stop errant interrupts until set up
 CLI(); //disable all interrupts
 port_init();

 MCUCR = 0x00;
 GICR  = 0x00;
 TIMSK = 0x00; //timer interrupt sources
 SEI(); //re-enable interrupts
 //all peripherals are now initialized
}

//
void main(void)
{
 unsigned char i,j;
 unsigned char n_clr;
       
 init_devices();
 LcdInit();
  
   for (i=1;i<21;i++)  for (j=3;j<8;j++)    LcdChr('A'+i-1,i,j); //char fill
   LcdStr("KS0108 driver  v1.5 ",1,1); // String  test
   LcdStr("(c)Zak  19 jan 2006 ",1,8); // String  test
   for (i=1;i<4;i++) LcdDrawIntN(i,3,i*4,2);
   InvStr(2,3,18);  
   for (i=33;i<55;i++)      for (j=30;j<54;j++)    LcdPixel(i,j,PIXEL_ON);
   for (i=55;i<77;i++)      for (j=30;j<54;j++)    LcdPixel(i,j,PIXEL_OFF);
   for (i=77;i<99;i++)      for (j=30;j<54;j++)    LcdPixel(i,j,PIXEL_XOR);

LcdLine(64,32,127, 0,PIXEL_ON);  //   
LcdLine(64,32,127,63,PIXEL_ON);  //   
LcdLine(64,32,  0, 0,PIXEL_ON);  //  
LcdLine(64,32,  0,63,PIXEL_ON);  //   
LcdLine(64, 1,64 ,63,PIXEL_ON);  //      |
LcdLine( 1,32,127,32,PIXEL_ON);  //      -

//LcdClear();

  
while(1)
{

 if (n_clr>0) n_clr--;
 	    
 if (!(PINB & btn_left)) ////   "<"   Left
    if (n_clr==0)
	  {  
        for (i=1;i<21;i++)  for (j=1;j<9;j++)    LcdChr('A'+i-1,i,j); //char fill
		n_clr=230;
      }	
 if (!(PINB & btn_up)) ////  "^"  UP
    if (n_clr==0)
	  {  
       for (j=2;j<8;j++) InvStr(j,j,10);

     	n_clr=230;
	  }	
     	 
 if (!(PINB & btn_right)) ////   ">"   right
      if (n_clr==0)
	  {
	   LcdInit();
	   LcdStr("reinit OK",4,5);
         for (i=0;i<127;i++) LcdLine(64,32,  i,0,PIXEL_XOR);
         for (i=0; i<63;i++) LcdLine(64,32,127,i,PIXEL_XOR);
         for (i=127;i>0;i--) LcdLine(64,32,  i,63,PIXEL_XOR);
         for (i=63 ;i>0;i--) LcdLine(64,32, 0,i,PIXEL_XOR);
     	n_clr=230;
      }
 if (!(PINB & btn_down)) ////  "v"   down
      if (n_clr==0)
	  {  
       for (i=0;i<128;i++)  
        for (j=0;j<64;j++)
         LcdPixel(i,j,PIXEL_XOR);
     	n_clr=230;
      }
	  
}

}

